Sky — pysm v3.1.dev260

pysm:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- pysm v3.1.dev260 »
- Sky

# Sky

class `pysm.` `Sky`(nside=None, component_objects=None, component_config=None, preset_strings=None, output_unit=Unit("uK_RJ"), map_dist=None)

  Bases: `pysm.Model`

  This class is a convenience object that wraps together a group of component models. It acts like a single `pysm.Model` object, in that it is sub-classed from the `pysm.Model` template, and therefore has the same functionality.

  Attributes
    components: list(pysm.Model object)

      List of `pysm.Model` objects.

  Methods Summary

  `add_component`(self, component) |
  `get_emission`(self, freq[, weights]) | This function returns the emission at a frequency, set of frequencies, or over a bandpass.

  Methods Documentation

  `add_component`(self, component)
  `get_emission`(self, freq, weights=None)

    This function returns the emission at a frequency, set of frequencies, or over a bandpass.